@@ -25,7 +25,8 @@ private Q_SLOTS:
     void testParseQuoteCSVSingleLine();
     void testParseQuoteCSVMultipleLines();
     void testParseQuoteCSVDateRange();
-    void testDateRangeInCSVUrls();
+    void testDateRangeInUrls();
+    void testParseQuoteJson();
 };
 
 #endif // ALKONLINEQUOTEPRIVATETEST_H
