@@ -49,8 +49,10 @@ public:
             None,
             Data,
             Date,
+            DatePattern,
             DateFormat,
             Price,
+            PricePattern,
             Script,
             Source,
             Symbol,
