@@ -11,6 +11,7 @@
 
 #include <alkimia/alkonlinequotesprofile.h>
 
+#include <QMetaType>
 #include <QString>
 
 class AlkOnlineQuotesProfile;
@@ -38,6 +39,7 @@ public:
         HTML,
         CSV,
         CSS,
+        JSON,
     };
 
     /**
@@ -172,6 +174,15 @@ public:
      * @return true required two identifier
      */
     bool requiresTwoIdentifier() const;
+
+    /**
+     * Return state if this source supports a date range
+     * @return true source supports a date range
+     * @return false source does not support a date range
+     * @since 8.1.90
+     */
+    bool supportsDateRange() const;
+
     QString ghnsWriteFileName() const;
     void setProfile(AlkOnlineQuotesProfile *profile);
     AlkOnlineQuotesProfile *profile();
@@ -181,6 +192,7 @@ protected:
     class Private;
     Private *d;
 };
+Q_DECLARE_METATYPE(AlkOnlineQuoteSource::DataFormat)
 
 inline void swap(AlkOnlineQuoteSource& first, AlkOnlineQuoteSource& second) // krazy:exclude=inline
 {
